@@ -146,9 +146,6 @@ void MainWindow::initGUI()
     m_viewModel = new QStandardItemModel(this);
     m_viewSwitcher->setModel(m_viewModel);
 
-    QAptActions *actions = QAptActions::self();
-    actions->setMainWindow(this);
-
     setupActions();
     setupGUI(StandardWindowOption(KXmlGuiWindow::Default & ~KXmlGuiWindow::StatusBar));
 }
