@@ -254,12 +254,12 @@ QVector<QPair<QString, QString> > Application::locateApplication(const QString &
 
 QStringList Application::categories()
 {
-    QStringList categories = QString(getField("Categories")).split(',', QString::SkipEmptyParts);
+    QStringList categories = QString(getField("Categories")).split(';', QString::SkipEmptyParts);
 
     if (categories.isEmpty()) {
         // extras.ubuntu.com packages can have this field
         if (m_isExtrasApp)
-            categories += package()->controlField(QLatin1String("Category"));
+            categories = package()->controlField(QLatin1String("Category")).split(';');
     }
     return categories;
 }
