@@ -131,6 +131,8 @@ void ResourcesModel::addResourcesBackend(AbstractResourcesBackend* backend)
 
     if(m_initializingBackends==0)
         emit allInitialized();
+    else
+        emit fetchingChanged();
 }
 
 AbstractResource* ResourcesModel::resourceAt(int row) const
@@ -227,7 +229,11 @@ void ResourcesModel::cleanBackend(AbstractResourcesBackend* backend)
         before+= it->size();
     }
     
-    beginRemoveRows(QModelIndex(), before, before+backendsResources->count()-1);
+    if (backendsResources->isEmpty()) {
+        return;
+    }
+    
+    beginRemoveRows(QModelIndex(), before, before + backendsResources->count() - 1);
     backendsResources->clear();
     endRemoveRows();
 }
