@@ -34,7 +34,7 @@ class MUONPRIVATE_EXPORT ResourcesModel : public QAbstractListModel
 {
     Q_OBJECT
     Q_PROPERTY(int updatesCount READ updatesCount NOTIFY updatesCountChanged)
-    Q_PROPERTY(bool fetching READ isFetching NOTIFY allInitialized)
+    Q_PROPERTY(bool fetching READ isFetching NOTIFY fetchingChanged)
     public:
         enum Roles {
             NameRole = Qt::UserRole,
@@ -84,6 +84,7 @@ class MUONPRIVATE_EXPORT ResourcesModel : public QAbstractListModel
         void cancelTransaction(AbstractResource* app);
 
     signals:
+        void fetchingChanged();
         void allInitialized();
         void backendsChanged();
         void updatesCountChanged();
